summaryrefslogtreecommitdiff
path: root/plugins
diff options
context:
space:
mode:
Diffstat (limited to 'plugins')
-rwxr-xr-xplugins/Facebook/facebook/facebookapi_php5_restlib.php2
-rw-r--r--plugins/Facebook/facebook/jsonwrapper/JSON/JSON.php2
-rw-r--r--plugins/Facebook/facebookaction.php2
-rw-r--r--plugins/Facebook/facebookhome.php2
-rw-r--r--plugins/LinkbackPlugin.php2
-rw-r--r--plugins/Meteor/MeteorPlugin.php2
-rw-r--r--plugins/OpenID/openid.php4
-rwxr-xr-xplugins/TwitterBridge/daemons/synctwitterfriends.php8
-rwxr-xr-xplugins/TwitterBridge/daemons/twitterstatusfetcher.php8
-rw-r--r--plugins/UserFlag/flagprofile.php2
10 files changed, 17 insertions, 17 deletions
diff --git a/plugins/Facebook/facebook/facebookapi_php5_restlib.php b/plugins/Facebook/facebook/facebookapi_php5_restlib.php
index 781390002..c742df748 100755
--- a/plugins/Facebook/facebook/facebookapi_php5_restlib.php
+++ b/plugins/Facebook/facebook/facebookapi_php5_restlib.php
@@ -2951,7 +2951,7 @@ function toggleDisplay(id, type) {
/**
- * Bans a list of users from the app. Banned users cannot
+ * Bans a list of users from the app. Banned users can't
* access the app's canvas page and forums.
*
* @param array $uids an array of user ids
diff --git a/plugins/Facebook/facebook/jsonwrapper/JSON/JSON.php b/plugins/Facebook/facebook/jsonwrapper/JSON/JSON.php
index 92542b47d..0cddbddb4 100644
--- a/plugins/Facebook/facebook/jsonwrapper/JSON/JSON.php
+++ b/plugins/Facebook/facebook/jsonwrapper/JSON/JSON.php
@@ -124,7 +124,7 @@ class Services_JSON
* "{...}" syntax creates associative arrays
* instead of objects in decode().
* - SERVICES_JSON_SUPPRESS_ERRORS: error suppression.
- * Values which cannot be encoded (e.g. resources)
+ * Values which can't be encoded (e.g. resources)
* appear as NULL instead of throwing errors.
* By default, a deeply-nested resource will
* bubble up with an error, so all return values
diff --git a/plugins/Facebook/facebookaction.php b/plugins/Facebook/facebookaction.php
index 41bb43e97..2327694e4 100644
--- a/plugins/Facebook/facebookaction.php
+++ b/plugins/Facebook/facebookaction.php
@@ -513,7 +513,7 @@ class FacebookNoticeList extends NoticeList
/**
* show the list of notices
*
- * "Uses up" the stream by looping through it. So, probably cannot
+ * "Uses up" the stream by looping through it. So, probably can't
* be called twice on the same list.
*
* @return int count of notices listed.
diff --git a/plugins/Facebook/facebookhome.php b/plugins/Facebook/facebookhome.php
index ee6e6620b..91c0cc6b8 100644
--- a/plugins/Facebook/facebookhome.php
+++ b/plugins/Facebook/facebookhome.php
@@ -108,7 +108,7 @@ class FacebookhomeAction extends FacebookAction
$user = User::staticGet('nickname', $nickname);
if (!$user) {
- $this->showLoginForm(_("Server error. Could not get user."));
+ $this->showLoginForm(_("Server error - couldn't get user!"));
}
$flink = DB_DataObject::factory('foreign_link');
diff --git a/plugins/LinkbackPlugin.php b/plugins/LinkbackPlugin.php
index bc433b896..915d15c07 100644
--- a/plugins/LinkbackPlugin.php
+++ b/plugins/LinkbackPlugin.php
@@ -125,7 +125,7 @@ class LinkbackPlugin extends Plugin
if (!extension_loaded('xmlrpc')) {
if (!dl('xmlrpc.so')) {
- common_log(LOG_ERR, "Cannot pingback; xmlrpc extension not available.");
+ common_log(LOG_ERR, "Can't pingback; xmlrpc extension not available.");
}
}
diff --git a/plugins/Meteor/MeteorPlugin.php b/plugins/Meteor/MeteorPlugin.php
index f3cbc3eea..5b345d7c2 100644
--- a/plugins/Meteor/MeteorPlugin.php
+++ b/plugins/Meteor/MeteorPlugin.php
@@ -85,7 +85,7 @@ class MeteorPlugin extends RealtimePlugin
// May throw an exception.
$this->_socket = stream_socket_client("tcp://{$controlserver}:{$this->controlport}");
if (!$this->_socket) {
- throw new Exception("Could not connect to {$controlserver} on {$this->controlport}");
+ throw new Exception("Couldn't connect to {$controlserver} on {$this->controlport}");
}
}
diff --git a/plugins/OpenID/openid.php b/plugins/OpenID/openid.php
index 4a76a8791..c5f6d1713 100644
--- a/plugins/OpenID/openid.php
+++ b/plugins/OpenID/openid.php
@@ -36,7 +36,7 @@ function oid_store()
{
static $store = null;
if (!$store) {
- # Cannot be called statically
+ # Can't be called statically
$user = new User();
$conn = $user->getDatabaseConnection();
$store = new Auth_OpenID_MySQLStore($conn);
@@ -192,7 +192,7 @@ function oid_authenticate($openid_url, $returnto, $immediate=false)
$form_html = preg_replace('/&/', '&', $form_html);
- // Display an error if the form markup could not be generated;
+ // Display an error if the form markup couldn't be generated;
// otherwise, render the HTML.
if (Auth_OpenID::isFailure($form_html)) {
common_server_error(sprintf(_('Could not create OpenID form: %s'), $form_html->message));
diff --git a/plugins/UserFlag/flagprofile.php b/plugins/UserFlag/flagprofile.php
index 84c343c48..c72b74c6a 100644
--- a/plugins/UserFlag/flagprofile.php
+++ b/plugins/UserFlag/flagprofile.php
@@ -135,7 +135,7 @@ class FlagprofileAction extends Action
$ufp->created = common_sql_now();
if (!$ufp->insert()) {
- throw new ServerException(sprintf(_("Could not flag profile '%s' with flag '%s'."),
+ throw new ServerException(sprintf(_("Couldn't flag profile '%s' with flag '%s'."),
$this->profile->nickname, $this->flag));
}
diff --git a/plugins/TwitterBridge/daemons/synctwitterfriends.php b/plugins/TwitterBridge/daemons/synctwitterfriends.php
index 76410c7cb..c89c02eed 100755
--- a/plugins/TwitterBridge/daemons/synctwitterfriends.php
+++ b/plugins/TwitterBridge/daemons/synctwitterfriends.php
@@ -126,7 +126,7 @@ class SyncTwitterFriendsDaemon extends ParallelizingDaemon
$conn->disconnect();
// XXX: Could not find a less brutal way to blow
// away a cached connection
global $_DB_DATAOBJECT;
@@ -188,7 +188,7 @@ class SyncTwitterFriendsDaemon extends ParallelizingDaemon
if (empty($more_friends)) {
common_log(LOG_WARNING, $this->name() .
- " - Could not retrieve page $i " .
+ " - Couldn't retrieve page $i " .
"of Twitter user $flink->foreign_id friends.");
continue;
} else {
@@ -222,11 +222,11 @@ class SyncTwitterFriendsDaemon extends ParallelizingDaemon
if (!save_twitter_user($friend_id, $friend_name)) {
common_log(LOG_WARNING, $this-name() .
- " - Could not save $screen_name's friend, $friend_name.");
+ " - Couldn't save $screen_name's friend, $friend_name.");
continue;
}
- // Check to see if there is a related local user
+ // Check to see if there's a related local user
$friend_flink = Foreign_link::getByForeignID($friend_id,
TWITTER_SERVICE);
@@ -126,7 +126,7 @@ class SyncTwitterFriendsDaemon extends ParallelizingDaemon
$conn->disconnect();
- // XXX: Could not find a less brutal way to blow
+ // XXX: Couldn't find a less brutal way to blow
// away a cached connection
global $_DB_DATAOBJECT;
diff --git a/plugins/TwitterBridge/daemons/twitterstatusfetcher.php b/plugins/TwitterBridge/daemons/twitterstatusfetcher.php
index 5d0d83be3..25df0d839 100755
--- a/plugins/TwitterBridge/daemons/twitterstatusfetcher.php
+++ b/plugins/TwitterBridge/daemons/twitterstatusfetcher.php
@@ -147,7 +147,7 @@ class TwitterStatusFetcher extends ParallelizingDaemon
$conn->disconnect();
// XXX: Could not find a less brutal way to blow
// away a cached connection
global $_DB_DATAOBJECT;
@@ -158,7 +158,7 @@ class TwitterStatusFetcher extends ParallelizingDaemon
{
if (empty($flink)) {
common_log(LOG_WARNING, $this->name() .
- " - Cannot retrieve Foreign_link for foreign ID $fid");
+ " - Can't retrieve Foreign_link for foreign ID $fid");
return;
}
@@ -458,7 +458,7 @@ class TwitterStatusFetcher extends ParallelizingDaemon
$profile = Profile::staticGet($profile_id);
if (empty($profile)) {
- common_debug($this->name() . " - Could not get profile: $profile_id!");
+ common_debug($this->name() . " - Couldn't get profile: $profile_id!");
return;
}
@@ -537,7 +537,7 @@ class TwitterStatusFetcher extends ParallelizingDaemon
$ok = file_put_contents($avatarfile, $response->getBody());
if (!$ok) {
common_log(LOG_WARNING, $this->name() .
- " - Could not open file $filename");
+ " - Couldn't open file $filename");
return false;
}
} else {
@@ -147,7 +147,7 @@ class TwitterStatusFetcher extends ParallelizingDaemon
$conn->disconnect();
- // XXX: Could not find a less brutal way to blow
+ // XXX: Couldn't find a less brutal way to blow
// away a cached connection
global $_DB_DATAOBJECT;